@@ -13,7 +13,7 @@ __PACKAGE__->mk_accessors(qw(
     ));
 
 
-our $VERSION = '0.2.4';
+our $VERSION = '0.2.5';
 
 
 sub new
@@ -88,7 +88,7 @@ navigation links.
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ Calculates the HTML and returns it.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
@@ -188,7 +188,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-NavLinks-GenHtml>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-NavLinks-GenHtml>
 
 =item *
 
@@ -220,7 +220,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/HTML-Latemp-NavLinks-GenHtml>
+L<http://cpants.cpanauthors.org/dist/HTML-Latemp-NavLinks-GenHtml>
 
 =item *
 
@@ -251,7 +251,7 @@ L<http://deps.cpantesters.org/?module=HTML::Latemp::NavLinks::GenHtml>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-html-latemp-navlinks-genhtml at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-NavLinks-GenHtml>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=HTML-Latemp-NavLinks-GenHtml>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
