@@ -3,7 +3,7 @@ package HTML::Latemp::NavLinks::GenHtml::ArrowImages;
 use strict;
 use warnings;
 
-our $VERSION = '0.2.4';
+our $VERSION = '0.2.5';
 
 use vars qw($nav_buttons_html);
 
@@ -120,7 +120,7 @@ HTML::Latemp::NavLinks::GenHtml::ArrowImages - A class to generate the image-bas
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 SYNOPSIS
 
@@ -148,7 +148,7 @@ Calculates and returns the final HTML.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
@@ -226,7 +226,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-NavLinks-GenHtml>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-NavLinks-GenHtml>
 
 =item *
 
@@ -258,7 +258,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/HTML-Latemp-NavLinks-GenHtml>
+L<http://cpants.cpanauthors.org/dist/HTML-Latemp-NavLinks-GenHtml>
 
 =item *
 
@@ -289,7 +289,7 @@ L<http://deps.cpantesters.org/?module=HTML::Latemp::NavLinks::GenHtml>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-html-latemp-navlinks-genhtml at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-NavLinks-GenHtml>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=HTML-Latemp-NavLinks-GenHtml>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
